# Ricco
常用工具包

## Installation

```bash
pip install ricco
```

## 函数使用说明
### 文件存取工具
* rdf
* split_csv

### dataframe操作
* reset2name

### 文件转换工具
* csv2shp
* shp2csv

### 坐标转换工具
* BD2WGS
* GD2WGS

### 空间计算工具
* valid_check
* circum_pio_num_geo_aoi
* mark_tags_df

### 其他工具
* mkdir_2
* pinyin










